@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2010-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -43,7 +43,6 @@ from calculate.lib.utils.text import _u8
 from calculate.lib.variables.linux import LinuxDataVars, Linux
 
 from calculate.lib.cl_lang import setLocalTranslate, _
-from ldap import dn
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
 
@@ -1727,8 +1726,6 @@ class FlashDistributive(PartitionDistributive):
     def writeable(self, mp):
         """
         Перемонитровать в rw, при необходимости
-        :param dn:
-        :return:
         """
         if not check_rw(mp):
             # перемонитровать в rw
